@@ -33,7 +33,10 @@ def tilescache_wsgi(tiles_storage=None, map_server=None):
         if not os.path.exists(file_path):
             url = map_server.replace("{s}", s).replace("{z}", z).replace("{y}", y).replace("{x}", x)
             if not os.path.exists(file_dir):
-                os.makedirs(file_dir)
+                try:
+                    os.makedirs(file_dir)
+                except (urllib2.URLError, socket.timeout):
+                    return Response("500 can't create dir", status=500)
             try:
                 file_data = urllib2.urlopen(url, timeout=3).read()
             except (urllib2.URLError, socket.timeout):
